@@ -26,6 +26,7 @@
 
 #include "6502core.h"
 #include "beebmem.h"
+#include "beebsound.h"
 #include "disc8271.h"
 #include "sysvia.h"
 #include "uservia.h"
@@ -1220,6 +1221,9 @@ void Exec6502Instruction(void) {
   SysVIA_poll(Cycles);
   UserVIA_poll(Cycles);
   Disc8271_poll(Cycles);
+#ifdef SOUNDSUPPORT
+  Sound_Trigger(Cycles);
+#endif
 
   if ((NMIStatus) && (!OldNMIStatus)) DoNMI();
   };
