@@ -451,10 +451,12 @@ static void DoFastTable(void) {
 
 static void VideoStartOfFrame(void) {
   int tmp;
+  static int InterlaceFrame=0;
 #ifdef BEEB_DOTIME
   static int Have_GotTime=0;
   static struct tms previous,now;
   static int Time_FrameCount=0;
+
   double frametime;
   static CycleCountT OldCycles=0;
 
@@ -520,7 +522,12 @@ static void VideoStartOfFrame(void) {
     };
   };
 
-  IncTrigger(((CRTC_HorizontalTotal+1)*((VideoULA_ControlReg & 16)?1:2)),VideoTriggerCount); /* Number of 2MHz cycles until another scanline needs doing */
+  InterlaceFrame^=1;
+  if (InterlaceFrame) {
+    IncTrigger((2*(CRTC_HorizontalTotal+1)*((VideoULA_ControlReg & 16)?1:2)),VideoTriggerCount); /* Number of 2MHz cycles until another scanline needs doing */
+  } else {
+    IncTrigger(((CRTC_HorizontalTotal+1)*((VideoULA_ControlReg & 16)?1:2)),VideoTriggerCount); /* Number of 2MHz cycles until another scanline needs doing */
+  };
 }; /* VideoStartOfFrame */
 
 
@@ -821,7 +828,7 @@ void VideoDoScanLine(void) {
       DoCA1Int=1;
     } else {
       if (VideoState.CharLine!=-1)  {
-        IncTrigger((CRTC_HorizontalTotal+1)*((VideoULA_ControlReg & 16)?1:2)*10,VideoTriggerCount);
+        IncTrigger((CRTC_HorizontalTotal+1)*((VideoULA_ControlReg & 16)?1:2)*((VideoState.CharLine==1)?9:10),VideoTriggerCount);
       } else {
         IncTrigger((CRTC_HorizontalTotal+1)*((VideoULA_ControlReg & 16)?1:2),VideoTriggerCount);
       };
